@@ -1,41 +1,11 @@
 package DBIx::Skinny::Schema;
 use strict;
 use warnings;
+use DBIx::Skinny::Util;
 
 BEGIN {
-    if ($] <= 5.008000) {
-        require Encode;
-        *utf8_on = sub {
-            my ($class, $col, $data) = @_;
-            if ($class->is_utf8_column($col)) {
-                Encode::_utf8_on($data) unless Encode::is_utf8($data);
-            }
-            $data;
-        };
-        *utf8_off = sub {
-            my ($class, $col, $data) = @_;
-            if ($class->is_utf8_column($col)) {
-                Encode::_utf8_off($data) if Encode::is_utf8($data);
-            }
-            $data;
-        };
-    } else {
-        require utf8;
-        *utf8_on = sub {
-            my ($class, $col, $data) = @_;
-            if ($class->is_utf8_column($col)) {
-                utf8::decode($data) unless utf8::is_utf8($data);
-            }
-            $data;
-        };
-        *utf8_off = sub {
-            my ($class, $col, $data) = @_;
-            if ($class->is_utf8_column($col)) {
-                utf8::encode($data) if utf8::is_utf8($data);
-            }
-            $data;
-        };
-    }
+    *utf8_on  = DBIx::Skinny::Util::utf8_on;
+    *utf8_off = DBIx::Skinny::Util::utf8_off;
 }
 
 sub import {
@@ -75,6 +45,8 @@ sub install_table ($$) {
     my $class = caller;
     $class->schema_info->{_installing_table} = $table;
         $install_code->();
+    $class->schema_info->{$table}->{row_class} ||= DBIx::Skinny::Util::mk_row_class($class, $table);
+
     delete $class->schema_info->{_installing_table};
 }
 
@@ -92,6 +64,7 @@ sub pk {
 sub row_class ($) {
     my $row_class = shift;
 
+    DBIx::Skinny::Util::load_class($row_class) or die "$row_class not found or compile error.";
     my $class = caller;
     $class->schema_info->{
         $class->schema_info->{_installing_table}
